@@ -23,7 +23,6 @@ import threading
 from time import time
 from uuid import uuid4
 from warnings import warn
-import json
 import functools
 from contextlib import contextmanager
 
@@ -1154,18 +1153,9 @@ class Connection(RequestSessionBase):
     @_with_cnx_set
     @_open_only
     def call_service(self, regid, **kwargs):
-        json.dumps(kwargs) # This line ensure that people use serialisable
-                           # argument for call service. this is very important
-                           # to enforce that from start to make sure RPC
-                           # version is available.
-        self.info('calling service %s', regid)
+        self.debug('calling service %s', regid)
         service = self.vreg['services'].select(regid, self, **kwargs)
-        result = service.call(**kwargs)
-        json.dumps(result) # This line ensure that service have serialisable
-                           # output. this is very important to enforce that
-                           # from start to make sure RPC version is
-                           # available.
-        return result
+        return service.call(**kwargs)
 
     @_with_cnx_set
     @_open_only
