@@ -382,7 +382,7 @@ class Field(object):
         called by widgets which requires a vocabulary.
 
         It should return a list of tuple (label, value), where value
-        *must be a unicode string*, not a typed value.
+        *must be an unicode string*, not a typed value.
         """
         assert self.choices is not None
         if callable(self.choices):
@@ -1033,6 +1033,10 @@ class CompoundField(Field):
         # while it has no value, hence generating a false error.
         return list(self.fields)
 
+    @property
+    def needs_multipart(self):
+        return any(f.needs_multipart for f in self.fields)
+
 
 class RelationField(Field):
     """Use this field to edit a relation of an entity.
