@@ -22,20 +22,20 @@ from cubicweb.devtools.testlib import CubicWebTC
 class BreadCrumbsTC(CubicWebTC):
 
     def test_base(self):
-        req = self.request()
-        f1 = req.create_entity('Folder', name=u'par&ent')
-        f2 = req.create_entity('Folder', name=u'chi&ld')
-        self.execute('SET F2 filed_under F1 WHERE F1 eid %(f1)s, F2 eid %(f2)s',
-                     {'f1' : f1.eid, 'f2' : f2.eid})
-        self.commit()
-        self.assertEqual(f2.view('breadcrumbs'),
-                          '<a href="http://testing.fr/cubicweb/folder/%s" title="">chi&amp;ld</a>' % f2.eid)
-        childrset = f2.as_rset()
-        ibc = self.vreg['ctxcomponents'].select('breadcrumbs', self.request(), rset=childrset)
-        l = []
-        ibc.render(l.append)
-        self.assertEqual(''.join(l),
-                          """<span id="breadcrumbs" class="pathbar">&#160;&gt;&#160;<a href="http://testing.fr/cubicweb/Folder">Folder_plural</a>&#160;&gt;&#160;<a href="http://testing.fr/cubicweb/folder/%s" title="">par&amp;ent</a>&#160;&gt;&#160;
+        with self.admin_access.web_request() as req:
+            f1 = req.create_entity('Folder', name=u'par&ent')
+            f2 = req.create_entity('Folder', name=u'chi&ld')
+            req.cnx.execute('SET F2 filed_under F1 WHERE F1 eid %(f1)s, F2 eid %(f2)s',
+                            {'f1' : f1.eid, 'f2' : f2.eid})
+            req.cnx.commit()
+            self.assertEqual(f2.view('breadcrumbs'),
+                             '<a href="http://testing.fr/cubicweb/folder/%s" title="">chi&amp;ld</a>' % f2.eid)
+            childrset = f2.as_rset()
+            ibc = self.vreg['ctxcomponents'].select('breadcrumbs', req, rset=childrset)
+            l = []
+            ibc.render(l.append)
+            self.assertEqual(''.join(l),
+                             """<span id="breadcrumbs" class="pathbar">&#160;&gt;&#160;<a href="http://testing.fr/cubicweb/Folder">Folder_plural</a>&#160;&gt;&#160;<a href="http://testing.fr/cubicweb/folder/%s" title="">par&amp;ent</a>&#160;&gt;&#160;
 <a href="http://testing.fr/cubicweb/folder/%s" title="">chi&amp;ld</a></span>""" % (f1.eid, f2.eid))
 
 if __name__ == '__main__':
