@@ -97,7 +97,7 @@ class ProcessInformationView(StartupView):
         w(u'<h2>%s</h2>' % _('Repository'))
         w(u'<h3>%s</h3>' % _('resources usage'))
         w(u'<table>')
-        stats = repo.stats()
+        stats = self._cw.call_service('repo_stats')
         for element in sorted(stats):
             w(u'<tr><th align="left">%s</th><td>%s %s</td></tr>'
                    % (element, xml_escape(unicode(stats[element])),
@@ -105,7 +105,7 @@ class ProcessInformationView(StartupView):
         w(u'</table>')
         if req.cnx.is_repo_in_memory and req.user.is_in_group('managers'):
             w(u'<h3>%s</h3>' % _('opened sessions'))
-            sessions = repo._sessions.itervalues()
+            sessions = repo._sessions.values()
             if sessions:
                 w(u'<ul>')
                 for session in sessions:
@@ -131,19 +131,9 @@ class ProcessInformationView(StartupView):
             sessions = SESSION_MANAGER.current_sessions()
             w(u'<h3>%s</h3>' % _('opened web sessions'))
             if sessions:
-                n_no_cnx_sessions = 0
                 w(u'<ul>')
                 for session in sessions:
-                    if not session.cnx:
-                        # We do not want to list all sessions without cnx
-                        # Their session ID are useless, hence we just count them
-                        n_no_cnx_sessions += 1
-                        continue
-                    try:
-                        last_usage_time = session.cnx.check()
-                    except BadConnectionId:
-                        w(u'<li>%s (INVALID)</li>' % session.sessionid)
-                        continue
+                    last_usage_time = session.mtime
                     w(u'<li>%s (%s: %s)<br/>' % (
                         session.sessionid,
                         _('last usage'),
@@ -151,9 +141,6 @@ class ProcessInformationView(StartupView):
                     dict_to_html(w, session.data)
                     w(u'</li>')
                 w(u'</ul>')
-                if n_no_cnx_sessions > 0:
-                    w(u'<h3>%s %s</h3>' % (n_no_cnx_sessions,
-                                           _('web sessions without CNX')))
             else:
                 w(u'<p>%s</p>' % _('no web sessions found'))
 
