@@ -47,6 +47,7 @@ from warnings import warn
 
 from logilab.common import dictattr, tempattr
 from logilab.common.decorators import iclassmethod, cached
+from logilab.common.compat import any
 from logilab.common.textutils import splitstrip
 from logilab.common.deprecation import deprecated
 
@@ -110,6 +111,9 @@ class FieldsForm(form.Form):
     :attr:`fieldsets_in_order`
       sequence of fieldset names , to control order
 
+    :attr:`autocomplete`
+      set to False to add 'autocomplete=off' in the form open tag
+
     **Generic methods**
 
     .. automethod:: cubicweb.web.form.Form.field_by_name(name, role=None)
@@ -159,6 +163,7 @@ class FieldsForm(form.Form):
     form_buttons = None
     form_renderer_id = 'default'
     fieldsets_in_order = None
+    autocomplete = True
 
     @property
     def needs_multipart(self):
@@ -184,7 +189,7 @@ class FieldsForm(form.Form):
     def render(self, formvalues=None, renderer=None, **kwargs):
         """Render this form, using the `renderer` given as argument or the
         default according to :attr:`form_renderer_id`. The rendered form is
-        returned as a unicode string.
+        returned as an unicode string.
 
         `formvalues` is an optional dictionary containing values that will be
         considered as field's value.
